summaryrefslogtreecommitdiff
path: root/engine/dconf-engine-profile.c
diff options
context:
space:
mode:
Diffstat (limited to 'engine/dconf-engine-profile.c')
-rw-r--r--engine/dconf-engine-profile.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/dconf-engine-profile.c b/engine/dconf-engine-profile.c
index cc9f83f..b204bb4 100644
--- a/engine/dconf-engine-profile.c
+++ b/engine/dconf-engine-profile.c
@@ -189,12 +189,12 @@ static FILE *
dconf_engine_open_profile_file (const gchar *profile)
{
const gchar * const *xdg_data_dirs;
- const gchar *prefix = "/etc";
+ const gchar *prefix = SYSCONFDIR;
FILE *fp;
xdg_data_dirs = g_get_system_data_dirs ();
/* First time through, we check "/etc", then we check XDG_DATA_DIRS,
* in order. We stop looking as soon as we successfully open a file
* or in the case that we run out of XDG_DATA_DIRS.
*
@@ -189,12 +189,12 @@ static FILE *
FILE *fp;
xdg_data_dirs = g_get_system_data_dirs ();
- /* First time through, we check "/etc", then we check XDG_DATA_DIRS,
+ /* First time through, we check SYSCONFDIR, then we check XDG_DATA_DIRS,
* in order. We stop looking as soon as we successfully open a file
* or in the case that we run out of XDG_DATA_DIRS.